@@ -26,8 +26,10 @@
 //#include <klocale.h>
 //#include <kdebug.h>
 //#include "iostream"
+
 #include "adif.h"
-//using namespace std;
+#include <QDebug>
+
 /*
 This class is really not independant FROM the GUI as the numbers to codify the
 MODE and BANDS depend on the position of the band in the COMBO-box.
@@ -43,7 +45,7 @@ BAND	FREQS (MHz)	GUI
 40M	7.0	7.3	3
 30M	10	10.15	4
 20M	14	14.35	5
-17M	18.068	18.168	6	
+17M	18.068	18.168	6
 15M	21.0	21.45	7
 12M	24.89	24.99	8
 10M	28.0	29.7	9
@@ -73,16 +75,16 @@ Adif::Adif(){
 }
 
 Adif::~Adif(){
-//cout << " - Class ~Adif" << endl;    
+//cout << " - Class ~Adif" << endl;
 }
 
 
 int Adif::band2Int(const QString& tband){
-//cout << "- Class Adif::band2Int: #" << tband << "#" << endl;
-  sAux = tband.upper();
+//qDebug() << "- Class Adif::band2Int: #" << tband << "#" << endl;
+  sAux = tband.toUpper();
 
   if (sAux == "2190M"){
-    return 1000;	
+    return 1000;
   }else if (sAux == "160M"){
     return 0;
   }else if (sAux == "80M"){
@@ -144,9 +146,9 @@ int Adif::band2Int(const QString& tband){
 }
 
 int Adif::mode2Int(const QString& tmode){
-//cout << " - Class Adif::mode2Int: " << tmode << endl;
+//qDebug() << " - Class Adif::mode2Int: " << tmode << endl;
 
-  sAux = tmode.upper();
+  sAux = tmode.toUpper();
   if (sAux == "SSB"){
     return 0;
   }else if (sAux == "USB"){  // hamlib adaptation
@@ -276,17 +278,17 @@ int Adif::mode2Int(const QString& tmode){
 
 int Adif::freq2Int (const QString& tfreq){ // Receives MHz/String
 // Due to float precision the band limits are not exact!
-//cout << "Adif::freq2Int: " << tfreq << endl;
+//qDebug() << "Adif::freq2Int: " << tfreq << endl;
+
+    freq = (tfreq.toFloat());
 
-	freq = (tfreq.toFloat());
-	
    if ((freq >=0.135)&&(freq <=0.138)){
     return 1000;
    }else if ((freq >=1.7)&&(freq <=2)){
     return 0;
    }else if ((freq >=3.4)&&(freq <=4)){
     return 1;
-   }else if ((freq >= 5.101)&&(freq <=5.405)){
+   }else if ((freq >= 5.1)&&(freq <=5.405)){
     return 2;
    }else if ((freq >= 7)&&(freq <=7.4)){
     return 3;
@@ -343,10 +345,175 @@ int Adif::freq2Int (const QString& tfreq){ // Receives MHz/String
   }
 
 }
+QString Adif::int2Freq(int tband){
+//qDebug() << "Adif::int2Freq: " << QString::number(tband) << endl;
+  switch(tband){
+    case 1000:// The user does not want to continue without a call
+      return "0.135";
+    break;
+    case 0:
+      return "1.8";
+    break;
+    case 1:
+      return "3.7";
+    break;
+    case 2:
+      return "5.1";
+    break;
+    case 3:
+      return "7";
+    break;
+    case 4:
+      return "10.1";
+    break;
+    case 5:
+      return "14";
+    break;
+    case 6:
+      return "18.1";
+    break;
+    case 7:
+      return "21";
+    break;
+    case 8:
+      return "24.9";
+    break;
+    case 9:
+      return "28";
+    break;
+    case 10:
+      return "50";
+    break;
+    case 11:
+      return "70";
+    break;
+    case 12:
+      return "144";
+    break;
+    case 13:
+      return "220";
+    break;
+    case 14:
+      return "432";
+    break;
+    case 15:
+      return "902";
+    break;
+    case 16:
+      return "1240";
+    break;
+    case 17:
+      return "2400";
+    break;
+    case 1018:
+      return "3300";
+    break;
+    case 1019:
+      return "5650";
+    break;
+    case 1020:
+      return "10000";
+    break;
+    case 1021:
+      return "24000";
+    break;
+    case 1022:
+      return "47000";
+    break;
+    case 1023:
+      return "75500";
+    break;
+    case 1024:
+      return "119980";
+    break;
+    case 1025:
+      return "142000";
+    break;
+    case 1026:
+      return "241000";
+    break;
+        default: //
+          return "-1";
+         break;
+      }
+
+}
+
+
+QString Adif::freqCorrection (const double& freq){ // Receives MHz/String
+// Due to float precision the band limits are not exact!
+//qDebug() << "Adif::freqCorrection: " << tfreq << endl;
+
+//    freq = (tfreq.toFloat());
+
+   if ((freq >=0.135)&&(freq <=0.138)){
+    return "0.135";
+   }else if ((freq >=1)&&(freq <3)){
+    return "1.8";
+   }else if ((freq >=3)&&(freq <=4)){
+    return "3.7";
+   }else if ((freq >= 5)&&(freq <=5.405)){
+    return "5.10";
+   }else if ((freq >= 7)&&(freq <=7.4)){
+    return "7";
+  }else if ((freq >= 10.1)&&(freq <10.17)){
+    return "10.1";
+  }else if ((freq >= 14)&&(freq <=14.35)){
+    return "14";
+  }else if ((freq >= 18)&&(freq <=18.169)){
+    return "18.1";
+  }else if ((freq >= 21)&&(freq <=21.46)){
+    return "21";
+  }else if ((freq >= 24.88)&&(freq <=24.991)){
+    return "24.9";
+  }else if ((freq >=28)&&(freq <=29.8)){
+    return "28";
+  }else if ((freq >=50)&&(freq <=54)){
+    return "50";
+  }else if ((freq >=70)&&(freq <=71)){
+    return "70";
+  }else if ((freq >=144)&&(freq <=148)){
+     return "144";
+   }else if ((freq >=220)&&(freq <=225)){
+     return "220";
+   }else if ((freq >=420)&&(freq <=450)){
+     return "432";
+   }else if ((freq >=902)&&(freq <=928)){
+     return "902";
+   }else if ((freq >=1200)&&(freq <=1300)){
+     return "1240";
+   }else if ((freq >=2300)&&(freq <=2450)) {
+     return "2400";
+   }else if ((freq >=3300)&&(freq <=3500)) {
+     return "3300";
+   }else if ((freq >=5650)&&(freq <=5925)) {
+     return "5650";
+   }else if ((freq >=10000)&&(freq <=10500)) {
+     return "10000";
+   }else if ((freq >=24000)&&(freq <=24250)) {
+     return "24000";
+   }else if ((freq >=47000)&&(freq <=47200)) {
+     return "47000";
+   }else if ((freq >=75500)&&(freq <=81000)) {
+     return "75500";
+   }else if ((freq >=119980)&&(freq <=120020)) {
+     return "119980";
+   }else if ((freq >=142000)&&(freq <=149000)) {
+     return "142000";
+   }else if ((freq >=241000)&&(freq <=250000)) {
+     return "241000";
+  }else{
+//cout << "Adif::freq2Int: NOBAND found" << endl;
+    return "0";
+    // If Band is not in this "list" it is still not supported
+  }
+
+}
+
 
 QString Adif::getModeBandPlan(const QString& tfreq){ // (in MHz)
 // cout << "Adif::getModeBandPlan: " << tfreq << endl;
-	 freq = (tfreq.toFloat());
+     freq = (tfreq.toFloat());
 
 
 
@@ -417,79 +584,80 @@ QString Adif::freq2Band (const QString& tfreq){ // MHz
 
 
 //	return int2Band(freq2Int(QString::number(((tfreq.left(tfreq.find("."))).toInt()))));
-
-return int2Band(freq2Int( tfreq.left((tfreq.find("."))+2) ));
+//QString aux = tfreq;
+//TODO: Check that "indexOf() works here as find() in Qt3
+return int2Band(freq2Int( tfreq.left((tfreq.indexOf("."))+2) ));
 
 }
 
 QString Adif::int2Band(int tband){
 //cout << " - Class Adif::int2Band: " << QString::number(tband) << endl;
 
-	if (tband == 1000){
-		return "2190M";
-	}else if (tband == 0){
-		return "160M";
-	}else if (tband == 1){
-		return "80M";
-	}else if (tband == 2){
-		return "60M";
-	}else if (tband == 3){
-		return "40M";
-	}else if (tband == 4){
-		return "30M";
-	}else if (tband == 5){
-		return "20M";
-	}else if (tband == 6){
-		return "17M";
-	}else if (tband == 7){
-		return "15M";
-	}else if (tband == 8){
-		return "12M";
-	}else if (tband == 9){
-		return "10M";
-	}else if (tband == 10){
-		return "6M";
-	}else if (tband == 11){
-		return "4M";
-	}else if (tband == 12){
-		return "2M";
-	}else if (tband == 13){
-		return "125CM";
-	}else if (tband == 14){
-		return "70CM";
-	}else if (tband == 15){
-		return "33CM";
-	}else if (tband == 16){
-		return "23CM";
-	}else if (tband == 17){
-		return "13CM";
-	}else if (tband == 1018){
-		return "9CM";
-	}else if (tband == 1019){
-		return "6CM";
-	}else if (tband == 1020){
-		return "3CM";
-	}else if (tband == 1021){
-		return "1.25CM";
-	}else if (tband == 1022){
-		return "6MM";
-	}else if (tband == 1023){
-		return "4MM";
-	}else if (tband == 1024){
-		return "2.5MM";
-	}else if (tband == 1025){
-		return "2MM";
-	}else if (tband == 1026){
-		return "1MM";
-	}else{
-		return "NOBAND";
+    if (tband == 1000){
+        return "2190M";
+    }else if (tband == 0){
+        return "160M";
+    }else if (tband == 1){
+        return "80M";
+    }else if (tband == 2){
+        return "60M";
+    }else if (tband == 3){
+        return "40M";
+    }else if (tband == 4){
+        return "30M";
+    }else if (tband == 5){
+        return "20M";
+    }else if (tband == 6){
+        return "17M";
+    }else if (tband == 7){
+        return "15M";
+    }else if (tband == 8){
+        return "12M";
+    }else if (tband == 9){
+        return "10M";
+    }else if (tband == 10){
+        return "6M";
+    }else if (tband == 11){
+        return "4M";
+    }else if (tband == 12){
+        return "2M";
+    }else if (tband == 13){
+        return "125CM";
+    }else if (tband == 14){
+        return "70CM";
+    }else if (tband == 15){
+        return "33CM";
+    }else if (tband == 16){
+        return "23CM";
+    }else if (tband == 17){
+        return "13CM";
+    }else if (tband == 1018){
+        return "9CM";
+    }else if (tband == 1019){
+        return "6CM";
+    }else if (tband == 1020){
+        return "3CM";
+    }else if (tband == 1021){
+        return "1.25CM";
+    }else if (tband == 1022){
+        return "6MM";
+    }else if (tband == 1023){
+        return "4MM";
+    }else if (tband == 1024){
+        return "2.5MM";
+    }else if (tband == 1025){
+        return "2MM";
+    }else if (tband == 1026){
+        return "1MM";
+    }else{
+        return "NOBAND";
 //		return  QString::null;
     // If Band is not in this "list" it is still not supported
-	}
+    }
 
 }
 bool Adif::isCW(const QString& tfreq){ //(MHz)
-//cout << " - Class Adif::isCW" << endl;    
+//cout << " - Class Adif::isCW" << endl;
   // If i don't recognice if true/false i set FALSE (To help DX-Cluster SH/DX commands)
     if (getModeBandPlan(tfreq)=="CW"){
         return true;
@@ -500,7 +668,7 @@ bool Adif::isCW(const QString& tfreq){ //(MHz)
 }
 
 bool Adif::isSSB(const QString& tfreq){
-//cout << " - Class Adif::isCW" << endl;    
+//cout << " - Class Adif::isCW" << endl;
   // If i don't recognice if true/false i set FALSE (To help DX-Cluster SH/DX commands)
     if (getModeBandPlan(tfreq)=="SSB"){
         return true;
@@ -512,40 +680,40 @@ bool Adif::isSSB(const QString& tfreq){
 
 bool Adif::isHF(const QString& tfreq){ // (in MHz)
 
-	iInt = freq2Int(tfreq);
-//cout << " - Class Adif::isHF: (freq/numb)" << tfreq <<"/" <<QString::number(iInt)<< endl; 
-	// If i don't recognice I set FALSE (To help DX-Cluster SH/DX commands)
-	//TODO: The 1000 is to help the 2190M band. Its is pending the band combobox reorganization.
-	if (((iInt < 10) && (iInt>=0) ) || (iInt==1000) ){
-        	return true;
-   	}else{
-		return false;
-	}
+    iInt = freq2Int(tfreq);
+//cout << " - Class Adif::isHF: (freq/numb)" << tfreq <<"/" <<QString::number(iInt)<< endl;
+    // If i don't recognice I set FALSE (To help DX-Cluster SH/DX commands)
+    //TODO: The 1000 is to help the 2190M band. Its is pending the band combobox reorganization.
+    if (((iInt < 10) && (iInt>=0) ) || (iInt==1000) ){
+            return true;
+    }else{
+        return false;
+    }
 
 }
 
 bool Adif::isVHF(const QString& tfreq){ // (in MHz)
 // To check if 6m band or more only - returns FALSE as a default
 //cout << " - Class Adif::isVHF" << tfreq << endl;
-	
-	iInt = freq2Int(tfreq);
-//cout << " - Class Adif::isVHF: (freq/numb)" << tfreq <<"/" <<QString::number(iInt)<< endl; 
-	//TODO: The next line will be valid only until I
-	// reorder the bands so the 2190M band is HF
-	
-	if ((iInt >= 10) && (iInt != 1000)){ //6m or more
-		return true;
-	}else{
-		return false;
-	}
+
+    iInt = freq2Int(tfreq);
+//cout << " - Class Adif::isVHF: (freq/numb)" << tfreq <<"/" <<QString::number(iInt)<< endl;
+    //TODO: The next line will be valid only until I
+    // reorder the bands so the 2190M band is HF
+
+    if ((iInt >= 10) && (iInt != 1000)){ //6m or more
+        return true;
+    }else{
+        return false;
+    }
 }
 
 
 bool Adif::isWARC(const QString& tfreq){ // (in MHz)
-//cout << " - Class Adif::isWARC" << endl;    
+//cout << " - Class Adif::isWARC" << endl;
 // Just 30m, 17m or 12m (To help DX-Cluster SH/DX commands)
 iInt = freq2Int(tfreq);
-  if ((iInt == 4) | (iInt == 6) | (iInt == 8)){ //30m/17m/12m 
+  if ((iInt == 4) | (iInt == 6) | (iInt == 8)){ //30m/17m/12m
      return true;
   }else{
     return false;
@@ -554,13 +722,13 @@ iInt = freq2Int(tfreq);
 
 
 int Adif::continent2Number(const QString& tcont){
-// CONTINENTS AF=0, AN=1, AS=2, EU=3, NA=4, OC=5, SA=6     
-  sAux = tcont.stripWhiteSpace();
+// CONTINENTS AF=0, AN=1, AS=2, EU=3, NA=4, OC=5, SA=6
+  sAux = tcont.trimmed();
     if (sAux == "AF"){
     return 0;
-  }else if (sAux == "AN"){ 
+  }else if (sAux == "AN"){
     return 1;
-  }else if (sAux == "AS"){ 
+  }else if (sAux == "AS"){
     return 2;
   }else if (sAux == "EU"){
     return 3;
@@ -571,13 +739,13 @@ int Adif::continent2Number(const QString& tcont){
   }else if (sAux == "SA"){
     return 6;
   }else{
-  	return -1;
+    return -1;
   }
 }
 
 
 QString Adif::number2Continent(int tcont){
-// CONTINENTS AF=0, AN=1, AS=2, EU=3, NA=4, OC=5, SA=6     
+// CONTINENTS AF=0, AN=1, AS=2, EU=3, NA=4, OC=5, SA=6
    if (tcont == 0){
      return "AF";
   }else if (tcont == 1){
@@ -603,89 +771,89 @@ QString Adif::number2Continent(int tcont){
 // // Receives a Freq and returns the same freq but in MHz (in case it was received in KHz)
 //cout << "Adif::KHz2MHz: " << tfreq << endl;
 
-	return QString::number((tfreq.toFloat())/1000);
+    return QString::number((tfreq.toFloat())/1000);
 
 }
 
 
 int Adif::entity2AdifNumber(const QString& tPref){ // returns the ADIF number of an entity
-	if (tPref == "VE"){
-		return 1;
-	}else if (tPref == "ABU AIL IS"){
-		return 2;
-	}else if (tPref == "YA"){
-		return 3;
-	}else if (tPref == "3B6"){
-		return 4;
-	}else if (tPref == "OH0"){
-		return 5;
-	}else if (tPref == "KL"){
-		return 6;
-	}else if (tPref == "ZA"){
-		return 7;
-	}else if (tPref == "ALDABRA"){
-		return 8;
-	}else if (tPref == "KH8"){
-		return 9;
-	}else if (tPref == "FT5Z"){
-		return 10;
-	}else if (tPref == "VU4"){
-		return 11;
-	}else if (tPref == "VP2E"){
-		return 12;
-	}else if (tPref == "CE9"){
-		return 13;
-	}else if (tPref == "EK"){
-		return 14;
-	}else if (tPref == "UA9"){
-		return 15;
-	}else if (tPref == "ZL9"){
-		return 16;
-	}else if (tPref == "YV0"){
-		return 17;
-	}else if (tPref == "4J"){
-		return 18;
-	}else if (tPref == "BAJO NUEVO"){
-		return 19;
-	}else if (tPref == "KH1"){
-		return 20;
-	}else if (tPref == "EA6"){
-		return 21;
-	}else if (tPref == "T8"){
-		return 22;
-	}else if (tPref == "BLENHEIM REEF"){
-		return 23;
-	}else if (tPref == "3Y/B"){
-		return 24;
-	}else if (tPref == "BRITISH N. BORNEO"){
-		return 25;
-	}else if (tPref == "BRITISH SOMALI"){
-		return 26;
-	}else if (tPref == "EU"){
-		return 27;
-	}else if (tPref == "CANAL ZONE"){
-		return 28;
-	}else if (tPref == "EA8"){
-		return 29;
-	}else if (tPref == "CELEBE/MOLUCCA IS"){
-		return 30;
-	}else if (tPref == "T31"){
-		return 31;
-	}else if (tPref == "EA9"){
-		return 32;
+    if (tPref == "VE"){
+        return 1;
+    }else if (tPref == "ABU AIL IS"){
+        return 2;
+    }else if (tPref == "YA"){
+        return 3;
+    }else if (tPref == "3B6"){
+        return 4;
+    }else if (tPref == "OH0"){
+        return 5;
+    }else if (tPref == "KL"){
+        return 6;
+    }else if (tPref == "ZA"){
+        return 7;
+    }else if (tPref == "ALDABRA"){
+        return 8;
+    }else if (tPref == "KH8"){
+        return 9;
+    }else if (tPref == "FT5Z"){
+        return 10;
+    }else if (tPref == "VU4"){
+        return 11;
+    }else if (tPref == "VP2E"){
+        return 12;
+    }else if (tPref == "CE9"){
+        return 13;
+    }else if (tPref == "EK"){
+        return 14;
+    }else if (tPref == "UA9"){
+        return 15;
+    }else if (tPref == "ZL9"){
+        return 16;
+    }else if (tPref == "YV0"){
+        return 17;
+    }else if (tPref == "4J"){
+        return 18;
+    }else if (tPref == "BAJO NUEVO"){
+        return 19;
+    }else if (tPref == "KH1"){
+        return 20;
+    }else if (tPref == "EA6"){
+        return 21;
+    }else if (tPref == "T8"){
+        return 22;
+    }else if (tPref == "BLENHEIM REEF"){
+        return 23;
+    }else if (tPref == "3Y/B"){
+        return 24;
+    }else if (tPref == "BRITISH N. BORNEO"){
+        return 25;
+    }else if (tPref == "BRITISH SOMALI"){
+        return 26;
+    }else if (tPref == "EU"){
+        return 27;
+    }else if (tPref == "CANAL ZONE"){
+        return 28;
+    }else if (tPref == "EA8"){
+        return 29;
+    }else if (tPref == "CELEBE/MOLUCCA IS"){
+        return 30;
+    }else if (tPref == "T31"){
+        return 31;
+    }else if (tPref == "EA9"){
+        return 32;
 
-	}else{
-		return -1;
-	}
+    }else{
+        return -1;
+    }
 
 }
 
 bool Adif::ifValidBand(const QString& tband){
 //cout << "Adif::ifValidBand: " << tband << endl;
-	if (band2Int(tband)>1){
-		return true;
-	}else{
-		return false;
-	}
+    if (band2Int(tband)>1){
+        return true;
+    }else{
+        return false;
+    }
 }
 
