@@ -25,9 +25,7 @@
 #ifndef ADIF_H
 #define ADIF_H
 
-#include <qstring.h>
-//#include <QString>
-
+#include <QString>
 
  class Adif{
 /*
@@ -57,37 +55,39 @@ BAND FREQS (MHz) GUI
 13CM  2300...2450 16
 */
 // Freqs are in MHz with a "decimal ." (optional)
-// CONTINENTS AF=0, AN=1, AS=2, EU=3, NA=4, OC=5, SA=6     
+// CONTINENTS AF=0, AN=1, AS=2, EU=3, NA=4, OC=5, SA=6
 public:
 
-	Adif();
-	~Adif();
-	
-	int band2Int(const QString& tband);
-	int mode2Int(const QString& tmode);
-	int freq2Int (const QString& tfreq); //(in MHz)   // accepts a string like "144", "10"... the MegaHertz section of a frecuency
-	QString getModeBandPlan(const QString& tfreq); //(in MHz)
-	QString int2Band(int tband);
-	QString freq2Band (const QString& tfreq); // (in MHz) Accepts frecs and returns band
-	bool isHF(const QString& tfreq);   // (in MHz) Input is the same as in freq2Int
-	bool isVHF(const QString& tfreq);  // (in MHz) Input is the same as in freq2Int
-	bool isWARC(const QString& tfreq);  // (in MHz) Input is the same as in freq2Int
-	bool isCW(const QString& tfreq);  // Input is the same as in freq2Int
-	bool isSSB(const QString& tfreq);  // Input is the same as in freq2Int
+    Adif();
+    ~Adif();
+
+    int band2Int(const QString& tband);
+    int mode2Int(const QString& tmode);
+    int freq2Int (const QString& tfreq); //(in MHz)   // accepts a string like "144", "10"... the MegaHertz section of a frecuency
+    QString getModeBandPlan(const QString& tfreq); //(in MHz)
+    QString int2Band(int tband);
+    QString int2Freq(int tband);
+    QString freq2Band (const QString& tfreq); // (in MHz) Accepts frecs and returns band
+    QString freqCorrection (const double& tfreq); // (in MHz) Accepts frecs and returns freq in float
+    bool isHF(const QString& tfreq);   // (in MHz) Input is the same as in freq2Int
+    bool isVHF(const QString& tfreq);  // (in MHz) Input is the same as in freq2Int
+    bool isWARC(const QString& tfreq);  // (in MHz) Input is the same as in freq2Int
+    bool isCW(const QString& tfreq);  // Input is the same as in freq2Int
+    bool isSSB(const QString& tfreq);  // Input is the same as in freq2Int
   // The next functions are just to adapt the specific KLog GUI to this general ADIF class
 
-	int continent2Number(const QString& tcont);
-	QString number2Continent(int tcont);
-	int entity2AdifNumber(const QString& tPref); // returns the ADIF number of an entity
-	
-	QString KHz2MHz(const QString& tfreq);  // Receives a Freq in KHz and returns the same freq but in MHz.
-	bool ifValidBand(const QString& tband); // Checks if the QString is a valid string band
+    int continent2Number(const QString& tcont);
+    QString number2Continent(int tcont);
+    int entity2AdifNumber(const QString& tPref); // returns the ADIF number of an entity
+
+    QString KHz2MHz(const QString& tfreq);  // Receives a Freq in KHz and returns the same freq but in MHz.
+    bool ifValidBand(const QString& tband); // Checks if the QString is a valid string band
 
 private:
 
-	QString sAux;
-	int iInt;
-	float freq;
+    QString sAux;
+    int iInt;
+    float freq;
 
 };
 
