@@ -25,9 +25,10 @@
 
 #ifndef QSO_H
 #define QSO_H
-#include <qstring.h>
+#include <QString>
 //#include <qchar.h>
-#include <qdatetime.h>
+#include <QDateTime>
+#include <QDebug>
 
  #define CALL_LENGTH 15
 // Modes: 12
@@ -41,7 +42,7 @@ public:
   Qso (const int tnumb, const QString& tqrz, const int trstrx, const int trsttx, const QString& tmode, const QString& tband, const int tpower);
   // Next constructor is used to read log
   Qso (const int tnumb, const QDateTime tdateTime, const QString& tqrz, const int trstrx, const int trsttx, const QString& tband, const QString& tmode, const QString& tpower, const QString& tcomment);
-  Qso (const int tnumb, const QDateTime& tdateTime, const QString& tqrz, const int trstrx, const int trsttx, int tband, const QString& tmode, const int tpower, const QDate& tqslSen,  const QDate& tqslRec, const QString& tcomment);  
+  Qso (const int tnumb, const QDateTime& tdateTime, const QString& tqrz, const int trstrx, const int trsttx, int tband, const QString& tmode, const int tpower, const QDate& tqslSen,  const QDate& tqslRec, const QString& tcomment);
   ~Qso();
 
   void setQrz(const QString &tqrz);
@@ -60,7 +61,7 @@ public:
   QDate getDate() const;
 
   void setTime(QTime ttime);
-  QTime getTime() const;  
+  QTime getTime() const;
 
   void setRstrx(int trstrx);
   int getRstrx() const;
@@ -82,36 +83,36 @@ public:
   QString getFreq_RX() const;
 
   void setMode(const QString& tmode);
-  QString getMode() const;  
+  QString getMode() const;
 
-	void setPower(const QString& tpower);
-	QString getPower() const;
+    void setPower(const QString& tpower);
+    QString getPower() const;
 
-	void setrxPower(const QString& tpower);
-	QString getrxPower() const;
+    void setrxPower(const QString& tpower);
+    QString getrxPower() const;
 
-	void setDXCC (int tnumb);	// ADIF DXCC Country code
-	int getDXCC() const;		// ADIF DXCC Country code
+    void setDXCC (int tnumb);	// ADIF DXCC Country code
+    int getDXCC() const;		// ADIF DXCC Country code
 
-	void setCountry(const QString& tcountry);	// ADIF DXCC Country name
-	QString getCountry() const;			// ADIF DXCC Country name
+    void setCountry(const QString& tcountry);	// ADIF DXCC Country name
+    QString getCountry() const;			// ADIF DXCC Country name
 
-	void setMyCountry(const QString& tcountry);	// ADIF DXCC Country name
-	QString getMyCountry() const;			// ADIF DXCC Country name
+    void setMyCountry(const QString& tcountry);	// ADIF DXCC Country name
+    QString getMyCountry() const;			// ADIF DXCC Country name
 
-	void setAge (int tnumb);	// Contacted operator age in years
-	int getAge() const;		// Contacted operator age in years
+    void setAge (int tnumb);	// Contacted operator age in years
+    int getAge() const;		// Contacted operator age in years
 
-	void setAnt_az (int tnumb);	//Antenna azimut in degrees
-	int getAnt_az() const;		//Antenna azimut in degrees
-	void setAnt_el (int tnumb);	//Antenna elevation in degrees
-	int getAnt_el() const;		//Antenna elevation in degrees
+    void setAnt_az (int tnumb);	//Antenna azimut in degrees
+    int getAnt_az() const;		//Antenna azimut in degrees
+    void setAnt_el (int tnumb);	//Antenna elevation in degrees
+    int getAnt_el() const;		//Antenna elevation in degrees
 
 
-	void setA_index (int tnumb); // geomagnetic A index at the time of the QSO
-	int getA_index() const;	// geomagnetic A index at the time of the QSO
-	void setK_index (int tnumb); // geomagnetic K index at the time of the QSO
-	int getK_index() const;	// geomagnetic K index at the time of the QSO
+    void setA_index (int tnumb); // geomagnetic A index at the time of the QSO
+    int getA_index() const;	// geomagnetic A index at the time of the QSO
+    void setK_index (int tnumb); // geomagnetic K index at the time of the QSO
+    int getK_index() const;	// geomagnetic K index at the time of the QSO
 
 
    void setQslSenDateOn(QDate tdate);
@@ -140,7 +141,7 @@ public:
   bool sentTheQSL(); // Did i sent my QSL?
 
   void setComment(const QString &tcomment);
-  QString getComment()const;  
+  QString getComment()const;
 
   void setQslVia(const QString &tInfo); // (bureau, direct, ...)
   QString getQslVia() const;
@@ -175,10 +176,10 @@ public:
   int getLocalAwardNumber() const;      // management
 
   void setName(const QString &tname);
-  QString getName() const; 
+  QString getName() const;
 
   void setMyName(const QString &tname);
-  QString getMyName() const; 
+  QString getMyName() const;
 
   void setAddress (const QString& taddress);
   QString getAddress() const;
@@ -196,7 +197,7 @@ public:
   QString getARRLSect() const;
 
   void setContinent(const QString &tcont);
-  QString getContinent() const; 
+  QString getContinent() const;
 
   void setContactedOP(const QString &tqrz);
   QString getContactedOP() const;
@@ -248,23 +249,23 @@ public:
  void setMaxBursts (int tnumb);	//maximum length of meteor scatter bursts heard by the logging station, in seconds
  int getMaxBursts() const;
 
- void setNRBursts (int tnumb);	
+ void setNRBursts (int tnumb);
  int getNRBursts() const;
 
- void setNRPings (int tnumb);	
+ void setNRPings (int tnumb);
  int getNRPings() const;
 
- void setSFI (int tnumb);	
+ void setSFI (int tnumb);
  int getSFI() const;
 
  void setMSShower(const QString &tmsshower);	//For Meteor Scatter QSOs, the name of the meteor shower in progress
  QString getMSShower() const;
 
- void setOwnerCall(const QString &tstring);	
+ void setOwnerCall(const QString &tstring);
  QString getOwnerCall() const;
- void setPfx(const QString &tstring);	
+ void setPfx(const QString &tstring);
  QString getPfx() const;
- void setPrecedence(const QString &tstring);	
+ void setPrecedence(const QString &tstring);
  QString getPrecedence() const;
 
 void setMyRig (const QString& taux);
@@ -290,20 +291,20 @@ int getTenten() const;
 /////////////////////
 
 /********************* CONTESTS ********************/
-	void setSrx (int tnumb);
-	int getSrx() const;
-	void setSrx_string(const QString &tsrx);
-	QString getSrx_string() const;
-	void setStx (int tnumb);
-	int getStx() const;
-	void setStx_string(const QString &tstx);
-	QString getStx_string() const;
-	void setContestID(const QString &tcontestid); // Contest identifier
-	QString getContestID() const;                // Contest identifier
-	void setCheck(const QString &tcheck); // Contest check
-	QString getCheck() const;                // Contest check
-	void setClass(const QString &tcheck); // Contest Class
-	QString getClass() const;                // Contest Class
+    void setSrx (int tnumb);
+    int getSrx() const;
+    void setSrx_string(const QString &tsrx);
+    QString getSrx_string() const;
+    void setStx (int tnumb);
+    int getStx() const;
+    void setStx_string(const QString &tstx);
+    QString getStx_string() const;
+    void setContestID(const QString &tcontestid); // Contest identifier
+    QString getContestID() const;                // Contest identifier
+    void setCheck(const QString &tcheck); // Contest check
+    QString getCheck() const;                // Contest check
+    void setClass(const QString &tcheck); // Contest Class
+    QString getClass() const;                // Contest Class
 
 /********************* CONTESTS ********************/
 
@@ -314,9 +315,9 @@ int getTenten() const;
   void clearQso();
 
 private:
-	QString	sAux;	//Auxiliar variable
+    QString	sAux;	//Auxiliar variable
   QString qrz;        // CALL
-  int numb;           // 
+  int numb;           //
   QDateTime dateTime; // QSO_DATE/TIME_ON YYYYMMDD - Time HHMM (0000-2359)
   int rstrx;          // RST_RCVD
   int rsttx;          // RST_SENT
@@ -325,7 +326,7 @@ private:
   QString band;       // BAND
   QString band_rx;       // BAND_RX
 
-	int dxcc;	// ADIF DXCC country code
+    int dxcc;	// ADIF DXCC country code
   QString country;	// ADIF DXCC country Name
   QString mode;       // MODE
   QString rx_power;   // RX_PWR
@@ -346,7 +347,7 @@ private:
   QString manager;
   int qslHow;         // How is the qsl to be send
   QString gridSquare; // GRIDSQUARE (the DX's one)
-	QString myGridSquare; //(My grid)
+    QString myGridSquare; //(My grid)
   QString iota;       // IOTA
   QString localAward;	// Each Entity may have a local award reference (TPEA, WAS, ...)
   int localAwardNumber; // Just a help for award references management but not saved into the log
@@ -374,8 +375,8 @@ private:
   int maxbursts;	// maximum length of meteor scatter bursts heard by the logging station, in seconds
   QString msshower;
   QString prop_mode;  // PROP_MODE QSO propagation mode
-  int my_cqz;	
-  int my_ituz;	
+  int my_cqz;
+  int my_ituz;
   QString my_iota;
   QString my_city;
   QString my_country;
@@ -386,11 +387,11 @@ private:
   int nr_bursts;
   int nr_pings;
   int sfi;		// the solar flux at the time of the QSO
-  QString sat_mode;	
-  QString sat_name;	
-  QString owner_callsign;	
+  QString sat_mode;
+  QString sat_name;
+  QString owner_callsign;
   QString pfx;
-  QString precedence;	
+  QString precedence;
 
   QString my_rig;
   QString my_sig;
@@ -418,30 +419,28 @@ private:
 
 
   QString notes; // Multiline... but similar to comment?
-  QString rig; // Multiline... 
+  QString rig; // Multiline...
   QString qso_complete; //(Char)
 
 ///////////////////////////////////////////////////////
 
 /***************** CONTEST FIELDS *************************/
-	int srx;		//contest QSO received serial number
-	int stx;		//contest QSO transmitted serial number
-	QString srx_string; 	//contest QSO received information
-	QString stx_string; 	//contest QSO transmitted information
-	QString contest_id;	// Contest identifier
+    int srx;		//contest QSO received serial number
+    int stx;		//contest QSO transmitted serial number
+    QString srx_string; 	//contest QSO received information
+    QString stx_string; 	//contest QSO transmitted information
+    QString contest_id;	// Contest identifier
 /***************** CONTEST FIELDS *************************/
-	
-	// Checks that the data is not an ADIF field and replaces </> by a (/).
-	QString checkisNotAdif(const QString& tword);
-	QString checkLines(const QString& tword);
 
+    // Checks that the data is not an ADIF field and replaces </> by a (/).
+    QString checkisNotAdif(const QString& tword);
+    QString checkLines(const QString& tword);
 
-	
-	//QString band_rx; // In split oprations the RX band
-	
-	//cqz;		// CQ Zone 
-	//ituz;		// ITU Zone
-	//QString freq_rx;
+    //QString band_rx; // In split oprations the RX band
+
+    //cqz;		// CQ Zone
+    //ituz;		// ITU Zone
+    //QString freq_rx;
 
 };
 
