@@ -1,3 +1,5 @@
+//Added by qt3to4:
+//#include <Q3ValueList>
 /***************************************************************************
                           world.h  -  description
                              -------------------
@@ -24,22 +26,22 @@
  *****************************************************************************/
 #ifndef WORLD_H
 #define WORLD_H
-#ifndef HAVE_CONFIG_H
-#include <config.h>
-#endif
 const char SEPARATOR1 = ':';
 const char SEPARATOR2 = ',';
 #include <stdlib.h>
 #include <math.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qfile.h>
-#include <qmap.h>
-#include <qdir.h>
+#include <KDE/KLocale>
+#include <QTextStream>
+#include <QString>
+#include <QStringList>
+#include <QFile>
+#include <QMap>
+#include <QDir>
+#include <QDebug>
 #include "entity.h"
 
 
-typedef QValueList<Entity> Entities;
+typedef QList<Entity> Entities;
   static Entities entities;
 
 class World{
@@ -48,7 +50,6 @@ public:
 	World();
 	~World();
 
-	void create();
 	bool isWorldCreated();
 
 	int findEntity(const QString  string);	// If no Entity is found, we return "0"
@@ -101,6 +102,7 @@ private:
 //	EntityIIMap::Iteraror itCqMapi, itItuMapi;	//TODO Map entity/zone to do things faster
 	int getItuz(); // HACK: I should fool-proof this function adding a QString as a call to get the zone
 	int getCqz();  // HACK: I should fool-proof this function adding a QString as a call to get the zone
+	void createNullEntity(); //Creates a null entity that will be an entity in every world 
 
 
 };
